@@ -2,144 +2,159 @@
 <!DOCTYPE TS>
 <TS version="2.1" language="zh_CN">
 <context>
-    <name>mxselectsound</name>
+    <name>MainWindow</name>
     <message>
-        <location filename="../mxselectsound.ui" line="14"/>
-        <location filename="../mxselectsound.cpp" line="48"/>
-        <location filename="../mxselectsound.cpp" line="78"/>
-        <location filename="../mxselectsound.cpp" line="136"/>
-        <location filename="../mxselectsound.cpp" line="148"/>
-        <location filename="../mxselectsound.cpp" line="182"/>
-        <location filename="../mxselectsound.cpp" line="191"/>
+        <location filename="../mainwindow.ui" line="14"/>
+        <location filename="../mainwindow.cpp" line="48"/>
+        <location filename="../mainwindow.cpp" line="78"/>
+        <location filename="../mainwindow.cpp" line="136"/>
+        <location filename="../mainwindow.cpp" line="148"/>
+        <location filename="../mainwindow.cpp" line="182"/>
+        <location filename="../mainwindow.cpp" line="191"/>
         <source>MX Select Sound</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxselectsound.ui" line="28"/>
+        <location filename="../mainwindow.ui" line="28"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Your current default sound card is:&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxselectsound.ui" line="64"/>
+        <location filename="../mainwindow.ui" line="64"/>
         <source>Display help </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxselectsound.ui" line="67"/>
+        <location filename="../mainwindow.ui" line="67"/>
         <source>Help</source>
-        <translation>帮助(_H)</translation>
+        <translation type="unfinished">帮助(_H)</translation>
     </message>
     <message>
-        <location filename="../mxselectsound.ui" line="75"/>
+        <location filename="../mainwindow.ui" line="74"/>
         <source>Alt+H</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxselectsound.ui" line="104"/>
+        <location filename="../mainwindow.ui" line="103"/>
         <source>About this application</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxselectsound.ui" line="107"/>
+        <location filename="../mainwindow.ui" line="106"/>
         <source>About...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxselectsound.ui" line="115"/>
+        <location filename="../mainwindow.ui" line="113"/>
         <source>Alt+B</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxselectsound.ui" line="147"/>
+        <location filename="../mainwindow.ui" line="145"/>
         <source>Quit application</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxselectsound.ui" line="150"/>
+        <location filename="../mainwindow.ui" line="148"/>
         <source>Close</source>
-        <translation>关闭</translation>
+        <translation type="unfinished">关闭</translation>
     </message>
     <message>
-        <location filename="../mxselectsound.ui" line="158"/>
+        <location filename="../mainwindow.ui" line="155"/>
         <source>Alt+N</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxselectsound.ui" line="199"/>
+        <location filename="../mainwindow.ui" line="196"/>
         <source>Apply</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxselectsound.ui" line="222"/>
+        <location filename="../mainwindow.ui" line="218"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Select another sound card if necessary:&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxselectsound.ui" line="248"/>
+        <location filename="../mainwindow.ui" line="244"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;If your computer has more than one sound card, you can use this application to select the one to be default. &lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxselectsound.ui" line="294"/>
+        <location filename="../mainwindow.ui" line="290"/>
         <source>Test current sound card</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxselectsound.cpp" line="79"/>
+        <location filename="../mainwindow.cpp" line="79"/>
         <source>No sound cards/devices were found.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxselectsound.cpp" line="91"/>
-        <location filename="../mxselectsound.cpp" line="105"/>
+        <location filename="../mainwindow.cpp" line="91"/>
+        <location filename="../mainwindow.cpp" line="105"/>
         <source>none</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxselectsound.cpp" line="135"/>
+        <location filename="../mainwindow.cpp" line="135"/>
         <source>About MX Select Sound</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxselectsound.cpp" line="136"/>
+        <location filename="../mainwindow.cpp" line="136"/>
         <source>Version: </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxselectsound.cpp" line="137"/>
+        <location filename="../mainwindow.cpp" line="137"/>
         <source>Program for selecting the default sound card in MX Linux</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxselectsound.cpp" line="139"/>
+        <location filename="../mainwindow.cpp" line="139"/>
         <source>Copyright (c) MX Linux</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxselectsound.cpp" line="140"/>
-        <location filename="../mxselectsound.cpp" line="148"/>
+        <location filename="../mainwindow.cpp" line="140"/>
+        <location filename="../mainwindow.cpp" line="148"/>
         <source>License</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxselectsound.cpp" line="141"/>
+        <location filename="../mainwindow.cpp" line="141"/>
         <source>Changelog</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxselectsound.cpp" line="142"/>
+        <location filename="../mainwindow.cpp" line="142"/>
         <source>Cancel</source>
-        <translation>取消</translation>
+        <translation type="unfinished">取消</translation>
     </message>
     <message>
-        <location filename="../mxselectsound.cpp" line="157"/>
+        <location filename="../mainwindow.cpp" line="157"/>
         <source>&amp;Close</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mxselectsound.cpp" line="192"/>
+        <location filename="../mainwindow.cpp" line="192"/>
         <source>Could not play test sound.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>mxselectsound</name>
+    <message>
+        <source>Help</source>
+        <translation type="vanished">帮助(_H)</translation>
+    </message>
+    <message>
+        <source>Close</source>
+        <translation type="vanished">关闭</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="vanished">取消</translation>
+    </message>
+</context>
 </TS>
